=======
History
=======

0.1.0 (2019-03-26)
------------------

* First development release.

0.1.1 (2019-03-27)
==================

* Requests are converted to async calls;
* Code style is clean and Python 3 compatible.

0.1.2 (2019-03-27)
==================

* Add basic tests.


0.2.0 (2019-03-31)
------------------

* New version with different organisation of classes and functions;
* Sync ``query`` and async ``aquery`` functions to query Biomart;
* Sync ``list_*`` functions to retrieve available ``marts``, ``datasets``, ``filters`` and ``attributes``.

0.2.1 (2019-04-01)
==================

* Add tests.

0.2.2 (2019-04-01)
==================

* Basic functions working and tested;
* Fix documentation;
* Update requirements.

0.2.3 (2019-04-02)
==================

* Update requirements;
* Fix type hints for query functions;
* Reorganise query classes into a single class;
* Update documentation.
